import { Player, system } from '@minecraft/server';
import { getPlayer, randomN, sendAllMessage, sendPlayerMessage, timeStamp } from "../../../stuff/commonUtils";
import { Command } from '../../../stuff/handler';

export function jumpscarePlayer(target: Player, player: Player, ignoreCooldown = false) {
    if (!target || target?.hasTag(`ls-dead`) && target.id !== player.id) {
        player.sendMessage(`§cFailed to find player.`);
        player.playSound(`random.break`, { volume: 0.5, pitch: 8 });
        return;
    }

    const cooldown = player.getDynamicProperty(`jumpscare-cooldown`) as number;

    if ((cooldown ? cooldown > Date.now() : false) && target.id !== player.id && !ignoreCooldown) {
        sendPlayerMessage(player, `§cYou are on cooldown! §6${timeStamp((cooldown as number) - Date.now())}§c left.`);

        player.playSound(`random.break`, { volume: 0.5, pitch: 8 });
        return;
    }

    if (!target) {
        sendPlayerMessage(player, `§cFailed to find player.`);
        player.playSound(`random.break`, { volume: 0.5, pitch: 8 });
        return;
    }

    sendPlayerMessage(player, `§cJumpscared §6${target.name}`);
    target.addEffect(`darkness`, 60);
    target.playSound(`mob.warden.nearby_closest`, { volume: 0.2 });
    system.runTimeout(() => {
        target.playSound(`mob.enderdragon.growl`, { volume: 0.5 });
        target.playSound(`mob.enderdragon.death`, { volume: 0.5 });
        target.playSound(`mob.enderdragon.growl`, { pitch: 1.3, volume: 1 });
        target.playSound(`mob.enderdragon.death`, { pitch: 1.3, volume: 0.5 });
        target.playSound(`mob.warden.emerge`, { pitch: 0.5, volume: 0.3 });
        target.playSound(`mob.warden.emerge`, { pitch: 0.5, volume: 0.4 });
        target.playSound(`mob.warden.emerge`, { pitch: 0.5, volume: 0.5 });

        const randomnumber = randomN(1, 3);
        if (randomnumber === 1)
            target.onScreenDisplay.setTitle(`§c§lboo`);
        if (randomnumber === 2)
            target.onScreenDisplay.setTitle(`§c§lrahh!!`);
        if (randomnumber === 3)
            target.onScreenDisplay.setTitle(`§c§lbig roar`);
        target.onScreenDisplay.updateSubtitle(`§c§ljumpscared by ${player.name}`);
    }, 40);

    if (target.id !== player.id)
        player.setDynamicProperty(`jumpscare-cooldown`, Date.now() + 60000);
}

new Command({
    name: `jumpscare`,
    callback({ player, args }) {
        if (!player.hasTag(`ls-dead`)) return sendPlayerMessage(player, `§cOnly ghosts can run this command!`);

        const target = getPlayer(`${args.join(` `)}`);
        jumpscarePlayer(target, player);
    }
});