import { Vector3Utils } from "@minecraft/math";
import { ButtonState, EasingType, InputButton, InputInfo, InputPermissionCategory, Player, system, world } from "@minecraft/server";
import { getPlayer, sendAllMessage, sendPlayerMessage } from "../../../stuff/commonUtils";
import { Command } from "../../../stuff/handler";
import { config } from "../../../stuff/config";
import { lifesteal } from "../../databases";

export const ghostSpectateMap = new Map<string, string>();
export const spectateOffsetMap = new Map<string, number>();

new Command({
    name: `spectate`,
    helpMenu: `§e§lLifesteal Help Page -- spectate§r§g
> Spectate a player while being a ghost, this won't change your coords

> Usage: ${config.prefix}spectate <playerName>

> Examples: [
    ${config.prefix}spectate GBShadow550
]`,
    async callback({ player, args, cmdData }) {
        if (lifesteal.get(`spectating`) !== `true`) return sendPlayerMessage(player, `§cThis command is disabled!`);
        if (!player.hasTag(`ls-dead`)) return sendPlayerMessage(player, `§cOnly ghosts can run this command!`);
        if (!args[0]) return sendPlayerMessage(player, `${cmdData.helpMenu}`);

        const target = getPlayer(`${args.join(` `)}`);
        if (!target || target?.hasTag(`ls-dead`)) {
            player.sendMessage(`§cFailed to find player.`);
            player.playSound(`random.break`, { volume: 0.5, pitch: 8 });
            return;
        }

        if (ghostSpectateMap.has(player.name)) return sendPlayerMessage(player, `§cAlready spectating a player! Sneak to cancel`);

        player.camera.fade({ fadeColor: { red: 0, blue: 0, green: 0 }, fadeTime: { fadeInTime: 0.5, fadeOutTime: 0.5, holdTime: 0.5 } });
        await system.waitTicks(9);
        ghostSpectateMap.set(player.name, target.name);

        sendPlayerMessage(target, `§cGhost ${player.name} is watching you.`);
        sendPlayerMessage(player, `§7Sneak to stop spectating`);
    },
});

export function processSpectators() {
    for (const plr of ghostSpectateMap) {
        const player = getPlayer(plr[0]);
        const target = getPlayer(plr[1]);
        const offset = spectateOffsetMap.get(player.id) ?? 1;

        if (!player || !target) {
            if (player) player.camera.clear();
            ghostSpectateMap.delete(plr[0]);
            continue;
        }
        const loc = target.getHeadLocation();
        loc.y += 0.5;
        const movement = player.inputInfo.getMovementVector().y;
        if (offset < 2 && movement < 0) {
            spectateOffsetMap.set(player.id, offset - player.inputInfo.getMovementVector().y / 2);
        }
        if (offset > 0 && movement > 0) {
            spectateOffsetMap.set(player.id, offset - player.inputInfo.getMovementVector().y / 2);
        }

        player.camera.setCamera(`minecraft:free`, {
            location: Vector3Utils.subtract(loc, Vector3Utils.scale(player.getViewDirection(), offset)),
            facingLocation: Vector3Utils.add(loc, player.getViewDirection()),
            easeOptions: { easeType: EasingType.InSine, easeTime: 0.07 }
        });

        player.inputPermissions.setPermissionCategory(InputPermissionCategory.Movement, false);
        if (player.inputInfo.getButtonState(InputButton.Sneak) === ButtonState.Pressed) {
            ghostSpectateMap.delete(player.name);
            spectateOffsetMap.delete(player.id);
            player.inputPermissions.setPermissionCategory(InputPermissionCategory.Movement, true);

            sendPlayerMessage(target, `§cGhost ${player.name} is no longer watching you`);
        }
    }
}