import { GameMode, PaletteColor, Player, world } from '@minecraft/server';
import { addScore, sendAllMessage, sendPlayerMessage } from "../../stuff/commonUtils";
import { config } from '../../stuff/config';
import { Command, SlashCommandBuilder } from '../../stuff/handler';
import { processAllDeadplayers } from '../core_modules/ghostHandling';
import { heartShow } from './heartSubcommands/heartShow';
import { heartDisplay } from './heartSubcommands/heartDisplay';
import { heartNotify } from './heartSubcommands/heartNotify';
import { heartSet } from './heartSubcommands/staffOnly/heartSet';
import { heartSetMax } from './heartSubcommands/staffOnly/settings/heartSetMax';
import { heartEnvsteal } from './heartSubcommands/staffOnly/settings/heartEnvsteal';
import { heartEnvdrop } from './heartSubcommands/staffOnly/settings/heartEnvdrop';
import { heartAdd } from './heartSubcommands/staffOnly/heartAdd';
import { heartRemove } from './heartSubcommands/staffOnly/heartRemove';
import { heartGet } from './heartSubcommands/staffOnly/heartGet';
import { heartGain } from './heartSubcommands/staffOnly/settings/heartGain';
import { heartLose } from './heartSubcommands/staffOnly/settings/heartLose';
import { heartItemCap } from './heartSubcommands/staffOnly/settings/heartItemCap';
import { heartReset } from './heartSubcommands/staffOnly/heartReset';
import { heartCount } from './heartSubcommands/heartCount';
import { heartMaxHolBonus } from './heartSubcommands/staffOnly/settings/heartMaxHolBonus';

new Command({
    name: `heart`,
    helpMenu: `§e§lLifesteal Help Page -- heart§r§g
> Heart stuff

> Usage: ${config.prefix}heart <display/show/set/reset/max/etc>

> Args: [
    display - Toggles whether or not to display your health above your head
    show - Toggles whether or not to display your health to yourself
    notify - Toggles whether or not you get notified when losing a heart
    count - Tells you how many hearts you have

    set - Set a player's max health
    reset - Reset a player's health to the default
    max - Set (or get) the maximum amount of hearts a player can get
    envsteal - Toggle whether or not you lose hearts from natural causes (such as fall damage and mobs)
    envdrop - Whether to drop your heart or make it disappear forever when dying from natural causes
    add - Adds hearts to a player's max heart count
    remove - Remove hearts from a player's max heart count
    get - See how many hearts a player has
    gain - Set the amount of hearts gained when killing a player
    lose - Set the amount of hearts lost when getting killed
    itemcap - Sets the heart item cap (if hearts are more than or equal to this number, heart items won't work)
    maxholbonus - Sets the maximum Heart of Life bonus
]

> Examples: [
    ${config.prefix}heart display
    ${config.prefix}heart show
    ${config.prefix}heart notify
    ${config.prefix}heart count
    
    ${config.prefix}heart reset GBShadow550
    ${config.prefix}heart set GBShadow550 16
    ${config.prefix}heart max
    ${config.prefix}heart max 30
    ${config.prefix}heart envsteal true
    ${config.prefix}heart envsteal false
    ${config.prefix}heart envdrop true
    ${config.prefix}heart envdrop false
    ${config.prefix}heart add 5 GBShadow550
    ${config.prefix}heart remove 5 GBShadow550
    ${config.prefix}heart get GBShadow550
    ${config.prefix}heart gain 3
    ${config.prefix}heart lose 2
    ${config.prefix}heart itemcap 15
    ${config.prefix}heart itemcap
    ${config.prefix}heart maxholbonus 3
    ${config.prefix}heart maxholbonus 25
]`,

    altHelpMenu: `§e§lLifesteal Help Page -- heart§r§g
> Heart stuff

> Usage: ${config.prefix}heart <display/show/set/setmax>

> Args: [
    display - Toggles whether or not to display your health above your head
    show - Toggles whether or not to display your health to yourself
    notify - Toggles whether or not you get notified when losing a heart
    count - Tells you how many hearts you have
]

> Examples: [
    ${config.prefix}heart display
    ${config.prefix}heart show
    ${config.prefix}heart notify
    ${config.prefix}heart count
]`,
    callback({ player, args, cmdData }) {
        if (!args[0]) {
            if (!player.isOp() && !player.hasTag(`lifesteal-opped`))
                return sendPlayerMessage(player, cmdData.altHelpMenu);
            return sendPlayerMessage(player, cmdData.helpMenu.replaceAll(`§e`, `§9`).replaceAll(`§g`, `§u`));
        }

        const foundStaffSubCommand = staffSubCommands[args[0].toLowerCase()];
        const foundSubCommand = subCommands[args[0].toLowerCase()];

        if ((player.isOp() || player.hasTag(`lifesteal-opped`)) && foundStaffSubCommand) foundStaffSubCommand(player, args);
        else if (foundSubCommand) foundSubCommand(player, args);
        else sendPlayerMessage(player, `§cUnknown argument '${args[0]}'. Do ${config.prefix}help heart for more information on how to use this command`);
    }
});

type SubCommandMap = { [subCommand: string]: (player: Player, args: string[]) => void; };

const subCommands: SubCommandMap = {
    show: heartShow,
    display: heartDisplay,
    notify: heartNotify,
    count: heartCount
};

const staffSubCommands: SubCommandMap = {
    set: heartSet,
    reset: heartReset,
    max: heartSetMax,
    envsteal: heartEnvsteal,
    envdrop: heartEnvdrop,
    add: heartAdd,
    remove: heartRemove,
    get: heartGet,
    gain: heartGain,
    lose: heartLose,
    itemcap: heartItemCap,
    maxholbonus: heartMaxHolBonus,
};