import { GameMode, Player } from '@minecraft/server';
import { sendPlayerMessage, getPlayer, setScore, getScore } from '../../../../stuff/commonUtils';
import { lifesteal } from '../../../databases';
import { processAllDeadplayers } from '../../../core_modules/ghostHandling';

export function heartSet(player: Player, args: string[]) {
    if (args.length > 3) return sendPlayerMessage(player, `§cExtra arguments at the end of command`);
    const amount = args[2] ? +args[2] : +args[1];
    const target = args[2] || isNaN(amount) ? getPlayer(args[1]) : player;

    if (!target) return sendPlayerMessage(player, `§cCouldn't find a player with that name ('${args[1] ?? ``}')`);
    if (isNaN(amount) || !Number.isInteger(amount)) return sendPlayerMessage(player, `§cExpected integer ('${amount}')`);

    const maxHearts = +lifesteal.get(`maxhearts`);
    if (!maxHearts) {
        console.warn(`Lifesteal settings - maxhearts is undefined`);
        return sendPlayerMessage(player, `§cAn error occured while trying to run that command`);
    }
    if (amount > maxHearts || amount < 0) return sendPlayerMessage(player, `§cPlease input a value from 0-${maxHearts}`);

    setScore(target, `ls-death`, amount);

    if (target.hasTag(`ls-dead`)) {
        target.setGameMode(GameMode.survival);
        target.removeTag(`ls-dead`);
        target.onScreenDisplay.setActionBar(`§bYou have been revived!`);
    }

    processAllDeadplayers();

    const targetsHeartCount = getScore(target, `ls-death`);
    sendPlayerMessage(player, `§aSet ${target.name}'s hearts to ${amount} from ${targetsHeartCount}`);
}