import { CustomCommandParamType, CustomCommandResult, CustomCommandStatus, EntityInventoryComponent, Player, system } from '@minecraft/server';
import { deadplayers, revivelist } from "../databases";
import { sendAllMessage, sendPlayerMessage } from "../../stuff/commonUtils";
import { config } from '../../stuff/config';
import { Command, SlashCommandBuilder } from '../../stuff/handler';
import { processAllDeadplayers } from '../core_modules/ghostHandling';

SlashCommandBuilder.createCommand({
    commandInfo: {
        name: `ls:revive`,
        description: `Revive a player if they are eliminated. Requires a heart of life in hand to work`,
        permissionLevel: 0,
        // no way to set param type to something that changes (i think) so we just do a string
        mandatoryParameters: [{ name: `targetName`, type: CustomCommandParamType.String }]
    },
    callback(origin, targetName: string) {
        const player = origin.sourceEntity as Player;
        if (player?.typeId !== `minecraft:player`) return { status: CustomCommandStatus.Failure, message: `Not a player` };

        system.run(() => {
            reviveCommand(player, targetName);
        });

        return { status: CustomCommandStatus.Success };
    },
});

new Command({
    name: `revive`,
    helpMenu: `§e§lLifesteal Help Page -- revive§r§g
> Revive a player if they are eliminated. Requires a heart of life in hand to work

> Usage: ${config.prefix}revive <player>

> Examples: [
    ${config.prefix}revive GBShadow550
]`,
    callback({ player, args, cmdData }) {
        if (!args[0]) return sendPlayerMessage(player, cmdData.helpMenu);

        reviveCommand(player, args[0]);
    }
});

function reviveCommand(player: Player, targetName: string) {
    const inventory = player.getComponent(`inventory`);
    const item = inventory.container.getItem(player.selectedSlotIndex);
    if (!item || item.typeId !== `lifesteal:beacon_of_life`) return sendPlayerMessage(player, `§cYou must have a beacon of life in your hand to revive a player!`);

    const target = deadplayers.get(targetName);

    if (!target) {
        return sendPlayerMessage(player, `§cFailed to find player. Make sure the capitalization is correct and they are an eliminated player. Do §o/ls:deadplayers§r§c or §o?deadplayers§r§c for a list of eliminated players`);
    }

    revivelist.set(`${target.toLowerCase()}`, `${target.toLowerCase()}.,${player.name}`);
    deadplayers.delete(target);

    if (player.runCommand(`clear @s lifesteal:beacon_of_life 0 1`).successCount <= 0) return;
    sendAllMessage(`§b${player.name} has revived ${target}`);

    player.runCommand(`playsound heart_of_life_sound @a`);

    processAllDeadplayers();
}