import { CommandPermissionLevel, CommandResult, CustomCommandParamType, CustomCommandResult, CustomCommandStatus, EntityInventoryComponent, ItemStack, Player, system, world } from '@minecraft/server';
import { addScore, getScore, sendAllMessage, sendPlayerMessage } from "../../stuff/commonUtils";
import { config } from '../../stuff/config';
import { Command, SlashCommandBuilder } from '../../stuff/handler';

SlashCommandBuilder.createCommand({
    commandInfo: {
        name: `ls:withdraw`,
        description: `Withdraw hearts`,
        permissionLevel: 0,
        mandatoryParameters: [{ name: `amount`, type: CustomCommandParamType.Integer }],
    },
    callback(origin, amount: number) {
        const player = origin.sourceEntity as Player;
        if (player?.typeId !== `minecraft:player`) return { status: CustomCommandStatus.Failure, message: `Not a player` };
        if (amount < 1) return { status: CustomCommandStatus.Failure, message: `You cannot withdraw less than 1 heart!` };

        system.run(() => withdrawAmount(player, amount));

        return { status: CustomCommandStatus.Success };
    }
});

new Command({
    name: `withdraw`,
    helpMenu: `§e§lLifesteal Help Page -- withdraw§r§g
> Withdraw a certain amount of hearts into your inventory

> Usage: ${config.prefix}withdraw <amount>

> Examples: [
    ${config.prefix}withdraw 3
    ${config.prefix}withdraw 6
]`,
    callback({ player, args, cmdData }) {
        if (!args[0]) return sendPlayerMessage(player, cmdData.helpMenu);

        const amount = +args[0];
        if (!Number.isInteger(amount)) return sendPlayerMessage(player, `§cExpected integer ('${args[0]}')`);

        if (amount < 1) return sendPlayerMessage(player, `§cYou cannot withdraw less than 1 heart!`);

        withdrawAmount(player, amount);
    }
});

export function withdrawAmount(player: Player, amount: number) {
    if (amount < 1) return;
    else if (getScore(player, `ls-death`) <= amount) return sendPlayerMessage(player, `§cYou cannot withdraw more hearts than you currently have! (${getScore(player, `ls-death`)})`);

    addScore(player, `ls-death`, -amount);
    const inventory = player.getComponent(`inventory`).container;
    const inventorySize = inventory.size;
    for (let i = 0; i < inventorySize; i++) {
        let item = inventory.getItem(i);
        if (!item || item.typeId !== `lifesteal:heart`) continue;
        inventory.setItem(i, new ItemStack(item.typeId, item.amount));
    }

    const sendCommandFeedback = world.gameRules.sendCommandFeedback;
    player.runCommand(`gamerule sendcommandfeedback false`);
    player.runCommand(`give @s lifesteal:heart ${amount}`);
    player.runCommand(`gamerule sendcommandfeedback ${sendCommandFeedback}`);

    sendPlayerMessage(player, `§aWithdrew ${amount} heart(s)`);
}