import { Vector3Builder } from "@minecraft/math";
import { GameMode, Player, system, world } from "@minecraft/server";
import { deadplayers, lifesteal, revivelist } from "../databases";
import { getScore, sendPlayerMessage, setScore } from "../../stuff/commonUtils";

export function handleRevive(player: Player) {
    if (!player.hasTag(`ls-revive`)) return;
    if (!player.hasTag(`ls-dead`)) {
        player.removeTag(`ls-revive`);
        return;
    }

    const reviverName = revivelist.get(player.name.toLowerCase()).split(`.,`)[1];
    revivelist.delete(player.name.toLowerCase());
    deadplayers.delete(player.name);

    const extraHearts = getScore(player, `ls-extra-hearts`) ?? 0;
    const maxHolBonus = +lifesteal.get(`maxholbonus`);
    const holBonus = extraHearts > maxHolBonus ? maxHolBonus : extraHearts;

    const reviveAmount = +lifesteal.get(`reviveamount`);

    setScore(player, `ls-death`, reviveAmount + holBonus);

    if (player.getGameMode() === GameMode.spectator) player.setGameMode(GameMode.survival);

    player.removeTag(`ls-dead`);
    player.addEffect(`regeneration`, 20, { amplifier: 255, showParticles: false });
    player.addEffect(`resistance`, 60, { amplifier: 255, showParticles: false });

    const message = `§bYou were revived${reviverName ? ` by §f${reviverName}` : ``}§b!`;

    player.onScreenDisplay.setActionBar(message);
    sendPlayerMessage(player, message);

    if (holBonus > 0) sendPlayerMessage(player, `§bYou were given ${holBonus} extra heart${holBonus > 1 ? `s` : ``} because of your heart of life perk!`);

    if (player.getSpawnPoint()) {
        player.teleport(player.getSpawnPoint(), { dimension: player.getSpawnPoint().dimension });
    } else {
        const block = player.dimension.getTopmostBlock(world.getDefaultSpawnLocation());

        player.teleport(block.above(), { dimension: world.getDimension(`overworld`) });
    }

    return true;
}