import { ItemStack, Player, Scoreboard, system, world } from "@minecraft/server";
import { lifestealLogs } from "../databases";
import { killhistory, lifesteal } from "../databases";
import { addScore, getScore, randomN, sendAllMessage, sendPlayerMessage, setScore } from "../../stuff/commonUtils";

/**
 * Detect death system
 * (This is the core lifesteal mechanic, die and lose a heart, kill and gain one)
 */
world.afterEvents.entityDie.subscribe(data => {
    const player = data.deadEntity as Player;
    const target = player.target as Player;
    const score = getScore(player, `ls-death`);
    const now = new Date(), hours = ((now.getUTCHours() % 12 || 12) + ``).padStart(2, `0`);
    const minutes = (now.getUTCMinutes() + ``).padStart(2, `0`);
    const amorpm = now.getUTCHours() < 12 ? `AM` : `PM`;
    const date = `${hours}:${minutes} ${amorpm}`;
    const mode: string = lifesteal.get(`lifestealmode`);

    let heartsToAdd = +lifesteal.get(`heartgain`);
    const heartLostOnDeath = lifesteal.get(`heartlose`);

    if (mode.includes(`random`)) heartsToAdd = randomN(+mode.split(`-`)[1], +mode.split(`-`)[2]);

    if ((score - heartLostOnDeath) === 0) sendAllMessage(`§c${player.name} lost all their hearts`);

    // Heart changed notification
    if (!player.hasTag(`heart-notify-off`) && !player.hasTag(`ls-message-debounce`)) {
        if (lifesteal.get(`envsteal`) === `false` && !target) return;

        if (heartLostOnDeath < 0) {
            const absheartLostOnDeath = Math.abs(+heartLostOnDeath);
            sendPlayerMessage(player, `§aYou gained ${absheartLostOnDeath === 1 ? `a` : `${absheartLostOnDeath}`} ${absheartLostOnDeath === 1 ? `heart` : `hearts`}. (You now have §f${score + absheartLostOnDeath}§a hearts.)`);
        } else {
            sendPlayerMessage(player, `§cYou lost ${+heartLostOnDeath === 1 ? `a` : `${heartLostOnDeath}`} ${+heartLostOnDeath === 1 ? `heart` : `hearts`}. (You now have §6${score - heartLostOnDeath}§c hearts.)`);
        }
    }

    const killHis = killhistory.get(`killhistory`);
    if (player.typeId === `minecraft:player`) {
        killhistory.set(`killhistory`, `${killhistory.has(`killhistory`) ? `${killHis},` : ``}${player.name}..${target?.typeId === `minecraft:player` ? target?.name : `none`}..${Date.now()}`);

        if ((killhistory.get(`killhistory`) as string).length > 10000) {
            killhistory.clear();
        }
    }

    const envsteal = lifesteal.get(`envsteal`);
    const envdrop = lifesteal.get(`envdrop`);

    if (envsteal === `false` && (!target || target.typeId !== `minecraft:player` || player.typeId !== `minecraft:player`)) return;

    const hearts = score;
    const lowerThanLost = hearts < heartLostOnDeath;

    addScore(player, `ls-death`, -(+heartLostOnDeath));
    lifestealLogs.push(`§q${date} > ${player.name} lost ${heartLostOnDeath} heart(s)`);

    if (!target || target.typeId !== `minecraft:player` || player === target) {
        if (envdrop === `true`) {
            player.dimension.spawnItem(new ItemStack(`lifesteal:heart`, heartsToAdd), player.location);
        }
        return;
    }

    if (lowerThanLost === true) {
        addScore(player, `ls-death`, hearts);
        lifestealLogs.push(`§q${date} > ${target.name} gained ${hearts} heart(s) from killing ${player.name}`);
        return;
    }

    addScore(target, `ls-death`, heartsToAdd);
    lifestealLogs.push(`§q${date} > ${target.name} gained ${heartsToAdd} heart(s) from killing ${player.name}`);
}, { entityTypes: [`minecraft:player`] });