import { system, world } from "@minecraft/server";
import { ActionFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifestealVersion } from "../changelog";
import { lifesteal } from "../databases";
import { newFeatures } from "../changelog";
import { getScore, sendAllMessage, sendPlayerMessage } from "../../stuff/commonUtils";
import { config } from "../../stuff/config";
import { processAllDeadplayers } from "../core_modules/ghostHandling";
import { openWelcomeGui } from "../gui/welcome";

world.afterEvents.playerSpawn.subscribe(({ player, initialSpawn }) => {
    if (player.hasTag(`ls-dead`)) {
        player.camera.clear();
        processAllDeadplayers();
        function ghostWelcomeForm() {
            if (initialSpawn) return;
            const ghostWelcome = new ActionFormData()
                .title(`You died!`)
                .body(`§gYou have lost your last heart and have become a ghost!\n\n§bTo get revived, a player must use a Heart of Life item and revive you`)
                .button(`Alright`);
            ghostWelcome.show(player).then(result => {
                if (result.canceled && result.cancelationReason == `UserBusy`) return ghostWelcomeForm();
            });
        }
        ghostWelcomeForm();
    }

    if (!initialSpawn) return;

    if (player.hasTag(config.staffTag) && player.hasTag(`welcome-gui_done`) && !player.hasTag(`lsversion-${lifestealVersion}`)) {
        const tags = player.getTags();
        for (const tag of tags) {
            if (tag.startsWith(`lsversion-`)) {
                player.removeTag(tag);
            }
        }

        player.addTag(`lsversion-${lifestealVersion}`);

        function newFeaturesFunction() {
            const gui = new ActionFormData()
                .title(`Lifesteal Changelog`)
                .body(`${newFeatures.replaceAll(`•`, `§r•§a`)}`)
                .button(`Ok`);
            gui.show(player).then(result => {
                if (result.canceled && result.cancelationReason === FormCancelationReason.UserBusy) newFeaturesFunction();
            });
        }
        newFeaturesFunction();
    }

    system.runTimeout(() => {
        let eventCheck = true;
        try {
            player.triggerEvent(`lifesteal:health-${getScore(player, `ls-death`)}`);
        } catch (error) {
            eventCheck = false;
        }

        if (!eventCheck && lifesteal.get(`useplayerjson`) === `true` && !world.getDynamicProperty(`lifesteal:ignore-join-error`)) {
            sendAllMessage(`§cAn error occured while loading lifesteal. Things that might have went wrong:
- Scoreboards didn't add properly
- Another addon is using player.json and is incompatible with lifesteal

Lifesteal working properly? Ignore this message with §o/ls:joinerrorignore true§r§c or §o?joinerrorignore true`);
        }
    }, 20);


    player.addTag(`ls-player`);
    player.addEffect(`resistance`, 60, { amplifier: 255, showParticles: false });

    // running player.sendmessage in playerSpawn causes a spike for some reason 
    sendPlayerMessage(player, `Lifesteal version: ${lifestealVersion}
Command Prefix: §l${config.prefix}§r | Get started by doing §l${config.prefix}help§r
Support the mod creator! https://patreon.com/gamerdos`);

    player.getTags()?.forEach(x => {
        if (x.startsWith(`lsh-`)) {
            player.removeTag(x);
        }
    });

    processAllDeadplayers();

    if (!player.hasTag("welcome-gui_done")) {
        player.addTag("welcome-gui_done");
        openWelcomeGui(player);
    }
});