import { Player } from "@minecraft/server";
import { ActionFormData, FormCancelationReason, uiManager } from "@minecraft/server-ui";
import { sendPlayerMessage } from "../../stuff/commonUtils";
import { agLifestealSettings } from "./adminpanel/settings";
import { agQuickCommands } from "./adminpanel/quickCommands";
import { agKillHistory } from "./adminpanel/killhistory";
import { agChangelog } from "./adminpanel/changelogGui";

export function adminPanel(player: Player) {
    const agMain = new ActionFormData()
        .title(`Admin Panel`)
        .button(`Lifesteal Settings`, `textures/ui/gear.png`)
        .button(`Quick Commands`, `textures/ui/op.png`)
        .button(`Kill History`, `textures/ui/WarningGlyph.png`)
        .button(`Lifesteal Changelogs`, `textures/items/map_filled.png`)
        .button(`Close`, `textures/ui/cancel.png`);
    agMain.show(player).then(result => {
        uiManager.closeAllForms(player);
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserBusy) return adminPanel(player);

        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
        switch (result.selection) {
            default:
                sendPlayerMessage(player, `§3Admin Panel Closed`);
                break;
            case 0:
                agLifestealSettings(player);
                break;
            case 1:
                agQuickCommands(player);
                break;
            case 2:
                agKillHistory(player);
                break;
            case 3:
                agChangelog(player);
                break;
        }
    });
}

type guiToReturnTo = `main` | `settings` | `quickcommands` | `killhistory`;

export function successGui(player: Player, guiName: string, guiMessage: string, guiToReturnTo: guiToReturnTo) {
    player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
    const gui = new ActionFormData()
        .title(guiName)
        .body(guiMessage)
        .button(`Back to Admin Panel`, `textures/ui/back_button_default.png`)
        .button(`Close Admin Panel`, `textures/ui/cancel.png`);
    gui.show(player).then(result => {
        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
        if (result.selection === 1) return sendPlayerMessage(player, `§3Admin Panel Closed`);
        switch (guiToReturnTo) {
            default:
                throw new Error(`No gui found (${guiToReturnTo})`);
            case `main`:
                adminPanel(player);
                break;
            case `settings`:
                agLifestealSettings(player);
                break;
            case `quickcommands`:
                agQuickCommands(player);
                break;
            case `killhistory`:
                agKillHistory(player);
                break;
        }
    });
}

export function getFormattedTime() {
    const now = new Date(), hours = ((now.getUTCHours() % 12 || 12) + ``).padStart(2, `0`);
    const minutes = (now.getUTCMinutes() + ``).padStart(2, `0`);
    const amorpm = now.getUTCHours() < 12 ? `AM` : `PM`;
    const date = `${hours}:${minutes} ${amorpm}`;
    return date;
}