import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason, MessageFormData } from "@minecraft/server-ui";
import { lifesteal } from "../../../databases";
import { successGui } from "../../adminpanel";
import { defaultSettings } from "../../../defaultSettings";


export function resetSettingsGui(player: Player) {
    const gui = new ModalFormData()
        .title(`Solve to confirm`)
        .textField(`Who was the creator of minecraft>`, `Notch or Herobrine`)
        .submitButton(`Reset all settings`);
    gui.show(player).then(result => {
        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
        const { formValues, cancelationReason, canceled } = result;
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            successGui(player, `Failed to reset settings`, `§cCanceled`, `settings`);
            return;
        }

        const text = formValues[0] as string;
        if (text.toLowerCase() !== `notch`) {
            successGui(player, `Failed to reset settings`, `§cWrong name!`, `settings`);
            return;
        }

        const confirm = new MessageFormData()
            .title(`Are you really sure?`)
            .body(`Are you §8really §rsure you want to reset all lifesteal settings?`)
            .button1(`No`)
            .button2(`Yes`);
        confirm.show(player).then(result => {
            const { selection, canceled, cancelationReason } = result;
            if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed || selection === 0) {
                successGui(player, `Failed to reset settings`, `§cCanceled`, `settings`);
                return;
            }

            lifesteal.clear();
            for (const key in defaultSettings) {
                if (!lifesteal.has(key)) {
                    lifesteal.set(key, defaultSettings[key as keyof typeof defaultSettings]);
                }
            }

            successGui(player, `Success!`, `§aReset all lifesteal settings to their default§r§7\n\n${Object.entries(defaultSettings).map(x => `${x[0]} - ${x[1]}`).join(`\n`)}`, `settings`);
        });
    });
}
