import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifesteal, lifestealLogs } from "../../../databases";
import { defaultSettings } from "../../../defaultSettings";
import { successGui, getFormattedTime } from "../../adminpanel";


export function setGhostBarrier(player: Player) {
    const gui = new ModalFormData()
        .title(`Ghost Barrier Radius`)
        .textField(`How far ghosts can go before being teleported to spawn`, `Write "disable" to disable the barrier`, {
            defaultValue: lifesteal.get(`ghostbarrier`) === `disabled` ? `disable` : lifesteal.get(`ghostbarrier`),
            tooltip: `Default: ${defaultSettings.ghostbarrier}`
        })
        .submitButton(`Set GB Radius`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change Ghost Barrier`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        if (isNaN(+formValues[0]) && formValues[0] !== `disable`) {
            return successGui(player, `Failed to change Ghost Barrier`, `§cNot a Number`, `settings`);
        }
        if (+formValues[0] < 5) {
            return successGui(player, `Failed to change Ghost Barrier`, `§cGhost Barrier Radius can't be less than 5`, `settings`);
        }

        lifesteal.set(`ghostbarrier`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged the Ghost Barrier Radius to §f${formValues[0] === `disable` ? `disabled` : formValues[0]}§a!`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed the Ghost Barrier Radius to ${formValues[0]} `);
    });
}
