import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifesteal, lifestealLogs } from "../../../databases";
import { defaultSettings } from "../../../defaultSettings";
import { successGui, getFormattedTime } from "../../adminpanel";


export function setHeartGain(player: Player) {
    const gui = new ModalFormData()
        .title(`HeartGL - Gained`)
        .textField(`Set the amount of hearts gained per kill`, `Enter a number here`, { defaultValue: lifesteal.get(`heartgain`), tooltip: `Default: ${defaultSettings.heartgain}` })
        .submitButton(`Set hearts gained`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change HeartGL - Gain`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        if (isNaN(+formValues[0])) {
            return successGui(player, `Failed to change HeartGL - Gain`, `§cNot a Number`, `settings`);
        }

        lifesteal.set(`heartgain`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged the amount of hearts gained per kill to §f${formValues[0]}§a!`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed HeartGL - Gain to ${formValues[0]} `);
    });
}
