import { Player } from "@minecraft/server";
import { FormCancelationReason, ModalFormData } from "@minecraft/server-ui";
import { defaultSettings } from "../../../defaultSettings";
import { lifesteal, lifestealLogs } from "../../../databases";
import { successGui, getFormattedTime } from "../../adminpanel";

export function setHeartItemCap(player: Player) {
    const gui = new ModalFormData()
        .title(`Heart Item Cap`)
        .slider(`The Heart Item Cap is how many hearts you can have before the Heart Item stops working and you have to start killing`, 1, +lifesteal.get(`maxhearts`), { defaultValue: +lifesteal.get(`heartitemcap`), tooltip: `Default: ${defaultSettings.heartitemcap}` })
        .submitButton(`Set Heart Item Cap`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change Heart Item Cap`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        lifesteal.set(`heartitemcap`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged Heart Item Cap to §f${formValues[0]}§a!`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed the Heart Item Cap to ${formValues[0]}`);
    });
}