import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifesteal, lifestealLogs } from "../../../databases";
import { defaultSettings } from "../../../defaultSettings";
import { successGui, getFormattedTime } from "../../adminpanel";


export function setHeartLimit(player: Player) {
    const gui = new ModalFormData()
        .title(`Heart Limit`)
        .slider(`Set Heart Limit`, 10, 200, { defaultValue: +lifesteal.get(`maxhearts`), tooltip: `Default: ${defaultSettings.maxhearts}` })
        .submitButton(`Set heart limit`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change Heart Limit`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        lifesteal.set(`maxhearts`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged Heart Limit to §f${formValues[0]}§a!`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed the Heart Limit to ${formValues[0]} `);
    });
}
