import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifesteal, lifestealLogs } from "../../../databases";
import { defaultSettings } from "../../../defaultSettings";
import { successGui, getFormattedTime } from "../../adminpanel";


export function setHeartLose(player: Player) {
    const gui = new ModalFormData()
        .title(`HeartGL - Lose`)
        .textField(`Set the amount of hearts lost per death`, `Enter a number here`, { defaultValue: lifesteal.get(`heartlose`), tooltip: `Default: ${defaultSettings.heartlose}` })
        .submitButton(`Set hearts lost`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change HeartGL - Lose`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        if (isNaN(+formValues[0])) {
            return successGui(player, `Failed to change HeartGL - Lose`, `§cNot a Number`, `settings`);
        }

        lifesteal.set(`heartlose`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged the amount of hearts lost per death to §f${formValues[0]}§a!`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed HeartGL - Lose to ${formValues[0]} `);
    });
}
