import { Player } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifesteal, lifestealLogs } from "../../../databases";
import { defaultSettings } from "../../../defaultSettings";
import { successGui, getFormattedTime } from "../../adminpanel";


export function toggleSpectating(player: Player) {
    const gui = new ModalFormData()
        .title(`Ghosts Spectate`)
        .toggle(`Ghosts can spectate players? (This won't reveal coordinates)`, { defaultValue: JSON.parse(lifesteal.get(`spectating`)), tooltip: `Default: ${defaultSettings.spectating}` })
        .submitButton(`Set Ghosts Spectate`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            return successGui(player, `Failed to change Ghosts can spectate`, `§cCanceled`, `settings`);
        }
        const formValues = result.formValues;

        lifesteal.set(`spectating`, `${formValues[0]}`);

        successGui(player, `Success!`, `§aChanged Ghosts can spectate players? to §f${formValues[0]}§a!\n§7(${formValues[0] === true ? `Players with no hearts left can spectate alive players outside of spawn, but won't see their coordinates` : `Players with no hearts left will be stuck at spawn and won't be able to spectate alive players`})`, `settings`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} changed Ghosts can spectate players? to ${formValues[0]} `);
    });
}
