import { Player, ItemStack } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { lifestealLogs } from "../../../databases";
import { successGui, getFormattedTime } from "../../adminpanel";


export function qcGetItem(player: Player) {
    const options = [`Heart`, `Heart Fragment`, `Heart Essence`, `Beacon of Life`, `Heart of Life`, `Withdraw Heart`];
    const gui = new ModalFormData()
        .title(`Get lifesteal item`)
        .dropdown(`Choose which item you want to get:`, options)
        .slider(`Amount`, 1, 64, { defaultValue: 64 })
        .submitButton(`Get item(s)`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) return successGui(player, `Failed to get item`, `§cCanceled`, `quickcommands`);
        const inventory = player.getComponent(`inventory`);
        const itemIndex = +result.formValues[0];
        const amount = +result.formValues[1];

        switch (itemIndex) {
            default:
                successGui(player, `Failed to get item`, `§cError`, `quickcommands`);
                break;
            case 0:
                inventory.container.addItem(new ItemStack(`lifesteal:heart`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Heart(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} heart(s)`);
                break;
            case 1:
                inventory.container.addItem(new ItemStack(`lifesteal:heart_fragment`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Heart Fragment(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} heart fragment(s)`);
                break;
            case 2:
                inventory.container.addItem(new ItemStack(`lifesteal:heart_essence`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Heart Essence(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} heart essence(s)`);
                break;
            case 3:
                inventory.container.addItem(new ItemStack(`lifesteal:beacon_of_life`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Beacon of Life(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} beacon of life(s)`);
                break;
            case 4:
                inventory.container.addItem(new ItemStack(`lifesteal:heart_of_life`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Heart of Life(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} heart of life(s)`);
                break;
            case 5:
                inventory.container.addItem(new ItemStack(`lifesteal:withdraw_heart`, amount));

                successGui(player, `Success!`, `§aGave yourself §f${amount} Withdraw Heart(s)`, `quickcommands`);
                lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} gave themselves ${amount} withdraw heart(s)`);
                break;
        }
    });
}
