import { Player, world, GameMode } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { setScore } from "../../../../stuff/commonUtils";
import { deadplayers, lifesteal, lifestealLogs } from "../../../databases";
import { successGui, getFormattedTime } from "../../adminpanel";
import { processAllDeadplayers } from "../../../core_modules/ghostHandling";


export function qcResetHearts(player: Player) {
    const players = world.getAllPlayers();
    const gui = new ModalFormData()
        .title(`Reset a player's heart count`)
        .dropdown(`Target player`, [...players.map(x => x.name), `Unselected`], { defaultValueIndex: players.length })
        .submitButton(`Reset Player's Hearts`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed || result.formValues[0] === players.length) {
            return successGui(player, `Failed to reset player's heart count`, `§cCanceled`, `quickcommands`);
        }

        const target = players[+result.formValues[0]];
        setScore(target, `ls-death`, +lifesteal.get(`startamount`));

        if (target.hasTag(`ls-dead`)) {
            target.setGameMode(GameMode.survival);
            target.removeTag(`ls-dead`);
            target.onScreenDisplay.setActionBar(`§bYou have been revived!`);
        }

        processAllDeadplayers();

        successGui(player, `Success!`, `§aReset ${target.name}${target.name.charAt(target.name.length - 1) === `s` ? `'` : `'s`} heart count`, `quickcommands`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} reset ${target.name}'s heart count`);
    });
}
