import { Player, world } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { sendPlayerMessage, sendAllMessage } from "../../../../stuff/commonUtils";
import { deadplayers, revivelist } from "../../../databases";
import { reviveGuiForm } from "../../reviveGui";
import { successGui } from "../../adminpanel";
import { processAllDeadplayers } from "../../../core_modules/ghostHandling";


export function qcRevivePlayer(player: Player) {
    const gui = new ModalFormData()
        .title(`Revive options`)
        .toggle(`Hide Revive (No message or sound)`)
        .toggle(`Revive all`);
    gui.show(player).then(async result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) return successGui(player, `Failed to revive`, `§cCanceled`, `quickcommands`);
        const hideRevive = result.formValues[0] as boolean;
        const reviveAll = result.formValues[1] as boolean;

        if (!reviveAll) {
            player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
            const revivedPlayer = await reviveGuiForm(player, false, hideRevive);
            if (revivedPlayer) successGui(player, `Success!`, `§aRevived ${revivedPlayer}`, `quickcommands`);
            else successGui(player, `Failed to revive player`, `§cCanceled`, `quickcommands`);
            return;
        }

        const reviver = hideRevive ? `` : `.,${player.name}`;
        for (const playerName of deadplayers.keys()) {
            revivelist.set(`${playerName.toLowerCase()}`, `${playerName.toLowerCase()}${reviver}`);
            deadplayers.delete(playerName);
        }
        processAllDeadplayers();

        if (hideRevive) return successGui(player, `Success!`, `§aRevived all players`, `quickcommands`);

        sendAllMessage(`§b${player.name} has revived all players`);

        for (const player of world.getAllPlayers()) {
            player.playSound(`heart_of_life_sound`);
        }

        successGui(player, `Success!`, `§aRevived all players`, `quickcommands`);
    });
}
