import { Player, world, Dimension, system } from "@minecraft/server";
import { ModalFormData, FormCancelationReason } from "@minecraft/server-ui";
import { getPlayer, sendAllMessage } from "../../../../stuff/commonUtils";
import { lifestealLogs } from "../../../databases";
import { successGui, getFormattedTime } from "../../adminpanel";

export function qcRunCommands(player: Player) {
    const gui = new ModalFormData()
        .title(`Run commands`)
        .slider(`How many commands would you like to run?`, 1, 30, { defaultValue: 3 })
        .textField(`Or enter an integer here (1-30)`, `Uses slider if invalid or < 1`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) return successGui(player, `Failed to run commands`, `§cCanceled`, `quickcommands`);
        const slider = result.formValues[0] as number;
        const timesToRun = Number.isInteger(+result.formValues[1]) &&
            +result.formValues[1] > 0
            ? +result.formValues[1] : slider;

        runCommandsGui(player, timesToRun > 30 ? 30 : timesToRun);
    });
}

function runCommandsGui(player: Player, inputFieldCount: number) {
    player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
    const players = [``].concat(world.getAllPlayers().map(x => x.name));
    const gui = new ModalFormData()
        .title(`Run commands`);
    for (let i = 1; i <= inputFieldCount; i++) {
        gui.textField(`Input ${i}`, `Enter a command here. / is optional`);
        gui.slider(`Times to run command`, 1, 100);
    }

    gui
        .dropdown(`Executor:`, [player.dimension.id, ...players.slice(1)])
        .submitButton(`Run`);
    gui.show(player).then(result => {
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed) {
            successGui(player, `Failed to run commands`, `§cCanceled`, `quickcommands`);
            return;
        }
        const executorIndex = +result.formValues[6];
        let executor: Dimension | Player;
        if (executorIndex > 0) {
            executor = getPlayer(players[executorIndex]);
        } else {
            executor = player.dimension;
        }

        const commmandsToRun = result.formValues.filter(x => typeof x === `string`);
        const timesToRun = result.formValues.filter(x => typeof x === `number`);

        const successes = runCommands(executor, commmandsToRun, timesToRun);

        const guiOutput = successes.map((v, i) => `§rInput ${i + 1}: ${v}`);
        const logsOutput = commmandsToRun.map((v, i) => `§r/${v} - §7${successes[i]}§r`).filter((_, i) => commmandsToRun[i]);

        successGui(player, `Ran commands`, `${guiOutput.join(`\n`)}`, `quickcommands`);
        lifestealLogs.push(`§q${getFormattedTime()} > ${player.name} ran commands using the Admin Panel as ${executorIndex === 0 ? executor.id : (executor as Player).name}:\n§o${logsOutput.length === 0 ? `§7No commands executed§r` : logsOutput.join(`\n`)}§r§g`);
    });
}

function runCommands(executor: Dimension | Player, commands: string[], timesToRun: number[]) {
    const successes: (string | number)[] = [];
    for (let i = 0; i < commands.length; i++) {
        if (!commands[i]) {
            successes[i] = `§7No command given§r`;
            continue;
        }

        let commandSuccessCount = 0;
        for (let current = 0; current < timesToRun[i]; current++) {
            try { commandSuccessCount += executor.runCommand(commands[i]).successCount; } catch (error) {
                successes[i] = `§c${error}§r`;
                break;
            }
        }

        if (!successes[i]) successes[i] = `§aRan ${commandSuccessCount} times§r`;
    }
    return successes;
}