import { PaletteColor, Player } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { adminPanel } from "../adminpanel";
import { setHeartLimit } from "./panelSettings/setHeartLimitGui";
import { setHeartGain } from "./panelSettings/setHeartGainGui";
import { setHeartLose } from "./panelSettings/setHeartLoseGui";
import { setBanGhosts } from "./panelSettings/setBanGhostsGui";
import { setEnvsteal } from "./panelSettings/setEnvstealGui";
import { setDefaultHearts } from "./panelSettings/setDefaultHeartsGui";
import { setHeartsOnRevive } from "./panelSettings/setHeartsOnReviveGui";
import { setGhostBarrier } from "./panelSettings/setGhostBarrierGui";
import { toggleSpectating } from "./panelSettings/toggleSpectatingGui";
import { resetSettingsGui } from "./panelSettings/resetSettingsGui";
import { setMaxHolBonus } from "./panelSettings/setMaxHolBonus";
import { sendAllMessage } from "../../../stuff/commonUtils";
import { setHeartItemCap } from "./panelSettings/setHeartItemCap";
import { setEnvdrop } from "./panelSettings/setEnvdropGui";

const settingsMap: { [buttonIndex: number]: (player: Player) => void; } = {
    0: setHeartLimit,
    1: setHeartGain,
    2: setHeartLose,
    3: setBanGhosts,
    4: setEnvdrop,
    5: setEnvsteal,
    6: setDefaultHearts,
    7: setHeartsOnRevive,
    8: setGhostBarrier,
    9: toggleSpectating,
    10: setMaxHolBonus,
    11: setHeartItemCap,
    12: resetSettingsGui,
};

export function agLifestealSettings(player: Player) {
    const gui = new ActionFormData()
        .title(`Lifesteal Settings`)
        .button(`Heart Limit`, `textures/ui/absorption_heart.png`)
        .button(`Hearts gained per Kill`, `textures/ui/heart_flash.png`)
        .button(`Hearts lost per Kill`, `textures/ui/heart_half.png`)
        .button(`Ban Ghosts`, `textures/ui/wither_heart_flash.png`)
        .button(`Drop Hearts from Natural Causes`, `textures/ui/poison_heart.png`)
        .button(`Lose Hearts from Natural Causes`, `textures/ui/poison_heart_flash.png`)
        .button(`Default amount of hearts`, `textures/items/withdraw_heart.png`)
        .button(`Amount of hearts when revived`, `textures/ui/freeze_heart_flash.png`)
        .button(`Radius ghosts can go within spawn`, `textures/ui/icon_map.png`)
        .button(`Spectating`, `textures/items/iron_chestplate.png`)
        .button(`Max Heart of Life Bonus`, `textures/items/heart_of_life.png`)
        .button(`Heart Item Cap`, `textures/ui/heart.png`)
        .button(`Reset all settings`, `textures/ui/refresh.png`)
        .button(`Back`, `textures/ui/back_button_default.png`);
    gui.show(player).then(result => {
        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });

        const settingsGui = settingsMap[result.selection];

        if (!settingsGui) return adminPanel(player);
        settingsGui(player);
    });
}