import { Player, system, world } from "@minecraft/server";
import { ActionFormData, FormCancelationReason, ModalFormData, uiManager } from "@minecraft/server-ui";
import { lifesteal } from "../databases";
import { ghostSpectateMap } from "../commands/ghostsOnly/spectate";
import { sendPlayerMessage } from "../../stuff/commonUtils";
import { jumpscarePlayer } from "../commands/ghostsOnly/jumpscare";

export function ghostPanel(player: Player) {
    const spectateOn = lifesteal.get(`spectating`);
    const gpMain = new ActionFormData()
        .title(`Ghost GUI`)
        .button(spectateOn === `true` ? `Spectate player` : `Spectate player\n§cDisabled`, `textures/ui/FriendsIcon.png`)
        .button(`Jumpscare player`, `textures/blocks/pumpkin_face_off.png`)
        .button(`Close`, `textures/ui/cancel.png`);
    gpMain.show(player).then(result => {
        uiManager.closeAllForms(player);
        if (result.canceled && result.cancelationReason === FormCancelationReason.UserBusy) return ghostPanel(player);
        const players = world.getAllPlayers();

        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });

        switch (result.selection) {
            default:
                player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
                break;
            case 0:
                if (spectateOn !== `true`) return ghostPanel(player);

                player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
                function spectateGUI() {
                    const gui = new ModalFormData()
                        .title(`Spectate player`)
                        .dropdown(`Players`, [...players.map(x => x.name), `Unselected`], { defaultValueIndex: players.length })
                        .submitButton(`Spectate`);
                    gui.show(player).then(async result => {
                        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
                        if (result.canceled || result.formValues[0] === players.length) return;

                        const formValues = result.formValues;

                        const target = players[formValues[0] as number];

                        if (!target || target?.hasTag(`ls-dead`)) {
                            if (target === player) return sendPlayerMessage(player, `§cYou cannot spectate yourself!`);
                            player.sendMessage(`§cFailed to find player.`);
                            player.playSound(`random.break`, { volume: 0.5, pitch: 8 });
                            return;
                        }

                        if (ghostSpectateMap.has(player.name)) return sendPlayerMessage(player, `§cAlready spectating a player! Sneak to cancel`);

                        player.camera.fade({ fadeColor: { red: 0, blue: 0, green: 0 }, fadeTime: { fadeInTime: 0.5, fadeOutTime: 0.5, holdTime: 0.5 } });
                        await system.waitTicks(9);
                        ghostSpectateMap.set(player.name, target.name);

                        sendPlayerMessage(target, `§cGhost ${player.name} is watching you.`);
                        sendPlayerMessage(player, `§7[Sneak] to stop spectating`);
                    });
                }
                spectateGUI();
                break;
            case 1:
                player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
                function jumpscareGUI() {
                    const gui = new ModalFormData()
                        .title(`Jumpscare player`)
                        .dropdown(`Players`, [...players.map(x => x.name), `Unselected`], { defaultValueIndex: players.length })
                        .submitButton(`Jumpscare`);
                    gui.show(player).then(result => {
                        player.playSound(`note.pling`, { pitch: 2, volume: 0.1 });
                        if (result.canceled || result.formValues[0] === players.length) return;
                        const formValues = result.formValues;

                        const target = players[formValues[0] as number];
                        jumpscarePlayer(target, player);
                    });
                }
                jumpscareGUI();
                break;
        }
    });
}