import { Block, Player, world } from "@minecraft/server";
import { ModalFormData, FormCancelationReason, ActionFormData } from "@minecraft/server-ui";
import { MinecraftBlockTypes } from "@minecraft/vanilla-data";
import { sendPlayerMessage, sendAllMessage } from "../../stuff/commonUtils";
import { processAllDeadplayers } from "../core_modules/ghostHandling";
import { deadplayers, revivelist } from "../databases";


export const beaconMap = new Map<string, Block>();
export const beaconDebounceMap = new Map<string, boolean>();

async function askForConfirmation(player: Player, target: string) {
    const gui = new ActionFormData()
        .title(`Are you sure?`)
        .body(`Reviving §a§o${target}`)
        .button(`Revive`, `textures/ui/realms_green_check.png`)
        .button(`Back`, `textures/ui/cancel.png`);
    return await gui.show(player).then(result => {
        if (result.canceled) return false;
        return result.selection === 0;
    });
}

export async function reviveGuiForm(player: Player, requireBeacon = true, hiddenRevive?: boolean) {
    let options = Array.from(deadplayers.keys());
    let target: string;

    while (target === undefined) {
        const noOptions = options.length === 0;

        const gui = new ModalFormData()
            .title(`Revive GUI`)
            .textField(`Search for a player`, `e.g GamerDos7511`)
            .dropdown(`Player to revive`, [...options, `Unselected`], { defaultValueIndex: options.length })
            .submitButton(`Revive`);
        await gui.show(player).then(async result => {
            if (result.canceled && result.cancelationReason === FormCancelationReason.UserBusy) return;

            if (result.canceled && result.cancelationReason === FormCancelationReason.UserClosed || result.formValues[1] === options.length && !result.formValues[0]) return target = null;

            const textField = result.formValues[0] as string;
            const dropdown = result.formValues[1] as number;
            const deadPlayersList = Array.from(deadplayers.keys());

            if (textField) {
                options = deadPlayersList.filter(x => x.includes(textField)
                );
                return;
            }
            if (noOptions) return target = null;

            if (await askForConfirmation(player, options[dropdown]))
                target = options[dropdown];
            else options = deadPlayersList;
        });
    }

    if (target === null) return;

    if (requireBeacon && beaconMap.has(player.id)) {
        const block = beaconMap.get(player.id);
        beaconMap.delete(player.id);

        if (block.typeId !== `lifesteal:beacon_of_life`) return;
        block.setType(MinecraftBlockTypes.Air);
    }
    else if (requireBeacon && player.runCommand(`clear @s lifesteal:beacon_of_life`).successCount <= 0 && !player.isOp()) return;

    const reviver = hiddenRevive ? `` : `.,${player.name}`;
    revivelist.set(`${target.toLowerCase()}`, `${target.toLowerCase()}${reviver}`);
    deadplayers.delete(target);
    processAllDeadplayers();

    if (hiddenRevive) {
        sendPlayerMessage(player, `§bRevived ${target}`);
        return target;
    }

    sendAllMessage(`§b${player.name} has revived ${target}`);

    for (const plr of world.getAllPlayers()) {
        plr.playSound(`heart_of_life_sound`);
    }
    return target;
}
