import { world } from "@minecraft/server";
import { config } from "./stuff/config";
import { lifestealLogs } from "./lifesteal/databases";
import { getScore, sendAllMessage } from "./stuff/commonUtils";

const scoreboards = [
    `ls-death`,
    `ls-nomsg`,
    `ls-extra-hearts`
];

/**
 * Lifesteal logs
 * 
 * this runs before the command handler. we need it to run before messages get canceled
 */
world.beforeEvents.chatSend.subscribe(data => {
    const findStart = config.prefixes.find(x => data.message.startsWith(x));
    if (data.message.startsWith(config.prefix) || findStart) {
        const now = new Date();
        const hours = ((now.getUTCHours() % 12 || 12) + ``).padStart(2, `0`);
        const minutes = (now.getUTCMinutes() + ``).padStart(2, `0`);
        const amorpm = now.getUTCHours() < 12 ? `AM` : `PM`;
        const date = `${hours}:${minutes} ${amorpm}`;
        lifestealLogs.push(`§q${date} > ${data.sender.name} used - ${data.message}`);
    }
});

import(`./lifesteal/commands/heart`);
import(`./lifesteal/commands/help`);
import(`./lifesteal/commands/revive`);
import(`./lifesteal/commands/version`);
import(`./lifesteal/commands/withdraw`);

import(`./lifesteal/commands/misc/deadplayers`);
import(`./lifesteal/commands/misc/welcome`);

import(`./lifesteal/commands/ghostsOnly/jumpscare`);
import(`./lifesteal/commands/ghostsOnly/spectate`);
import(`./lifesteal/commands/ghostsOnly/ghostpanel`);

import(`./lifesteal/commands/staffOnly/adminpanel`);
import(`./lifesteal/commands/staffOnly/logs`);
import(`./lifesteal/commands/staffOnly/op`);
import(`./lifesteal/commands/staffOnly/settings/banghosts`);
import(`./lifesteal/commands/staffOnly/settings/compatibility`);
import(`./lifesteal/commands/staffOnly/settings/ghostbarrier`);
import(`./lifesteal/commands/staffOnly/settings/reviveamount`);
import(`./lifesteal/commands/staffOnly/settings/startamount`);
import(`./lifesteal/commands/staffOnly/utility/forcerevive`);
import(`./lifesteal/commands/staffOnly/utility/get`);
import(`./lifesteal/commands/staffOnly/utility/kill`);
import(`./lifesteal/commands/staffOnly/utility/reviveall`);
import(`./lifesteal/commands/staffOnly/debug/fakeplayer`);
import(`./lifesteal/commands/staffOnly/debug/openReviveGui`);
import(`./lifesteal/commands/staffOnly/debug/settings`);
import(`./lifesteal/commands/staffOnly/debug/revivelist`);
import(`./lifesteal/commands/staffOnly/debug/deadplayersRaw`);
import(`./lifesteal/commands/staffOnly/debug/errorIgnore`);

import(`./lifesteal/events/system/beforeEvents/startUp`);

world.afterEvents.worldLoad.subscribe(() => {
    for (const scoreboard of scoreboards) {
        try { world.scoreboard.addObjective(scoreboard); } catch { }
    }
    try { world.scoreboard.addObjective(`hearts`, `§cHearts`); } catch { }

    import(`./lifesteal/events/beforeEvents/playerPlaceBlock`);
    import(`./lifesteal/events/entityDie`);
    import(`./lifesteal/events/itemUse`);
    import(`./lifesteal/events/playerSpawn`);
    import(`./lifesteal/runInterval`);

    import(`./lifesteal/core_modules/ghostHandling`);
    import(`./lifesteal/core_modules/reviveSystem`);
});